import {
  select,csv,pie,arc,scaleOrdinal,schemeCategory10,
} from 'd3';

 
const svg = select("svg");
const width = +svg.attr('width');
const height = +svg.attr('height');


const numberFormat = number =>
  	(Math.abs(Number(number)))   +" units per day ";


const render = data => {
  const pieData = pie().sort(null).value(d=>d['Total Sales'])(data);
  const colors = scaleOrdinal(schemeCategory10);
	const segments = arc()
  	.innerRadius(0)
  	.outerRadius(200)
  	.padAngle(0)
  	.padRadius(0);
  
  const sections = svg.append("g")
  	.attr("transform", `translate(250,250)`)
  	.selectAll("path").data(pieData);
  sections.enter().append("path").attr("d", segments)
  	.attr("fill", d => colors(d.data['Total Sales']))
  	.on("mouseover", d => console.log(d.data['Total Sales']));
  //piechart is created 
  const legends = svg.append("g")
  	.attr("transform", "translate(500,100)")
    .selectAll(".legends").data(pieData);
  const legend = legends.enter().append("g").classed(".legends",true)
  	.attr("transform", (d,i)=>{
      return `translate(0,${(i+1)*30})`;
    });
  
  

  legend.append("rect").attr("width",22).attr("height",25)
  	.attr("fill", d => colors(d.data['Total Sales']));
  legend.append("text")
  	.attr("x", 28)
  	.attr("y", 18)
  	.attr("class","legend_text")
  	.text(d => d.data['Restaurant']);
  legend.append("text")
  	.attr("x", 260)
  	.attr("y", 20)
  	.attr("class","legend_value")
  	.text(d=>numberFormat(d.data['Total Sales']));
}


const csvUrl =
 'https://gist.githubusercontent.com/maheganesh/daa9e2507084c1b809a622753cb807d4/raw/54ba3eb9fb480600f4e4b3244bc88037b0b1d716/Restaurent%2520sales.csv';
//Load the data 
csv(csvUrl).then(csvData => {
    csvData.sort((data1, data2) => data2['Total Sales']-data1['Total Sales']);
    if (csvData) {
      render(csvData.slice(0, 10));
    }
});